//
//
//   basic.cc - minimum implementation
//
//   Copyright (C) 2015 by Matt Roberts.
//   License: GNU GPL3 (www.gnu.org)
//
//

#include <beagle/GA.hpp>
#include <iostream>
#include "evalop.h"

using namespace Beagle;
using namespace Basic;

int main(int argc, char **argv) {
	try {
		// 1. Build the system.
		System::Handle lSystem = new System;

		// 2. Build evaluation operator.
		LoopEvalOp::Handle evalOp = new LoopEvalOp;

		// 3. Instanciate the evolver.
		GA::EvolverFloatVector::Handle evolver = new GA::EvolverFloatVector(evalOp, 2);

		// 4. Initialize the vivarium
		GA::FloatVector::Alloc::Handle theVector = new GA::FloatVector::Alloc;
		Vivarium::Handle lVivarium = new Vivarium(theVector);

		// 5. Initialize the evolver and evolve the vivarium.
		evolver->initialize(lSystem, argc, argv);
		evolver->evolve(lVivarium);
	}
	catch(Exception& inException) {
		inException.terminate(std::cerr);
	}
	catch(const std::exception& inException) {
		std::cerr << "std::exception:" << std::endl << std::flush;
		std::cerr << inException.what() << std::endl << std::flush;
		return 1;
	}
	return 0;
}
