//
//
//   config.h - loop design parameters
//
//   Copyright (C) 2015 by Matt Roberts.
//   License: GNU GPL3 (www.gnu.org)
//
//

#ifndef __LOOP_CONFIG_H
#define __LOOP_CONFIG_H

#include <cmath>

namespace LoopFormulae {
	//
	//  loop design configuration
	//
	class LoopConfig {
		//
		//  public fields -- these four items are the loop configuration variables;
		//                   the first two are required inputs from the user, while
		//                   the latter two are GP/GA outputs
		//
		public:
			// resonant frequency
			double f;

			// loop power
			double P;

			// loop shape diameter
			double w;

			// loop conductor diameter
			double d;

		public:
			static double Circle(double w);
			static double Square(double w);

			double (*AreaFunc)(double w);

		public:
			LoopConfig() { AreaFunc = Circle; }
	};

	double Efficiency(const LoopConfig &c);
	double Smallness(const LoopConfig &c);
	double Bandwidth(const LoopConfig &c);
	double BandwidthNorm(const LoopConfig &c);
	double Conductor(const LoopConfig &c);

	double Rr(const LoopConfig &c);
	double Rloss(const LoopConfig &c);
	double L(const LoopConfig &c);
	double XL(const LoopConfig &c);
	double Ct(const LoopConfig &c);
	double Q(const LoopConfig &c);
	double Cd(const LoopConfig &c);
	double Vc(const LoopConfig &c);
	double IL(const LoopConfig &c);
	double A(const LoopConfig &c);
	double S(const LoopConfig &c);
}

#endif // __LOOP_CONFIG_H
