//
//
//   fitness.h - fitness evaluation type
//
//   Copyright (C) 2015 by Matt Roberts.
//   License: GNU GPL3 (www.gnu.org)
//
//

#ifndef __LOOP_FITNESS_H
#define __LOOP_FITNESS_H

#include <vector>
#include "config.h"

namespace LoopFormulae {
	//
	//  FitnessElement - a single fitness evaluation item
	//
	struct FitnessElement {
		double Coef;
		double (*Func)(const LoopConfig &c);
		double Exp;

		FitnessElement() {
			Coef = 1.0;
			Func = 0;
			Exp = 1.0;
		}
	};

	//
	//  the product of either the numerator or denominator
	//
	typedef std::vector<FitnessElement> FitnessProduct;

	//
	//
	//   Fitness - the fitness evaluation type
	//
	//
	class Fitness {
		// private fields
		private:
			FitnessProduct m_Product;

		// constructors
		public:
			Fitness(const FitnessProduct &product);
			virtual ~Fitness();

			// compute the fitness value of a specific configuration
			double Value(const LoopConfig &c) const;
	};
}

#endif // __LOOP_FITNESS_H
