//
//
//   unittests.cc - test specific features in isolation
//
//   Copyright (C) 2015 by Matt Roberts.
//   License: GNU GPL3 (www.gnu.org)
//
//

#include <iostream>
#include "fitness.h"
#include "config.h"

using namespace LoopFormulae;


//
//  test formula calculations
//
static void FormulaeSanityChecks() {
	LoopConfig c;
	c.w = 4.4;
	c.P = 500;
	c.f = 7.030;
	c.d = 0.625;

	std::cout << "Loop config:" << std::endl;
	std::cout << " + f: " << c.f << " MHz" << std::endl;
	std::cout << " + P: " << c.P << " W" << std::endl;
	std::cout << " + d: " << c.d << " in" << std::endl;
	std::cout << " + w: " << c.w << " ft" << std::endl;
	std::cout << std::endl;
	std::cout << "Loop output:" << std::endl;
	std::cout << " + S: " << S(c) << " ft" << std::endl;
	std::cout << " + A: " << A(c) << " ft^2" << std::endl;
	std::cout << " + Rr: " << Rr(c) * 1000 << " mohms" << std::endl;
	std::cout << " + Rl: " << Rloss(c) * 1000 << " mohms" << std::endl;
	std::cout << " + Q : " << Q(c) << std::endl;
	std::cout << " + Ct: " << Ct(c) * pow(10, 12) << " pF" << std::endl;
	std::cout << " + Vc: " << Vc(c) / 1000 << " kV" << std::endl;
	std::cout << " + IL: " << IL(c) << " A" << std::endl;
	std::cout << " + L : " << L(c) * pow(10, 6) << " uH" << std::endl;
	std::cout << " + XL: " << XL(c) << " ohms" << std::endl;
	std::cout << " + n : " << Efficiency(c) * 100 << "%" << std::endl;
	std::cout << " + BW: " << Bandwidth(c) << " Hz" << std::endl;
	std::cout << " + Bn: " << BandwidthNorm(c) << std::endl;
	std::cout << " + Sm: " << Smallness(c) << std::endl;
	std::cout << " + Re: " << Conductor(c) << std::endl;
	std::cout << std::endl;
}

//
//  test the fitness function
//
static void FitnessUnitTest() {
	LoopConfig c;
	c.w = 4.4;
	c.P = 500;
	c.f = 7.030;
	c.d = 1.000;

	FitnessProduct p;
	FitnessElement e;
	e.Func = Efficiency;
	p.push_back(e);
	e.Func = Bandwidth;
	p.push_back(e);
	e.Func = Smallness;
	p.push_back(e);

	Fitness f(p);

	std::cout << "Fitness:" << std::endl;
	std::cout << " + Fitness (d: " << c.d << "; w: " << c.w << "): " << f.Value(c) << std::endl;
	c.d = 0.5;
	std::cout << " + Fitness (d: " << c.d << "; w: " << c.w << "): " << f.Value(c) << std::endl;
	c.d = 1.0;
	c.w = 4.3;
	std::cout << " + Fitness (d: " << c.d << "; w: " << c.w << "): " << f.Value(c) << std::endl;
}

//
//
//   main(...)
//
//
int main(int argc, char **arvg) {
	FormulaeSanityChecks();
	FitnessUnitTest();
}
